<?php
/**
* Plugin Markdown parser
*
* @package	PLX
* @version	1.0
* @date	28/09/16
* @author Bronco
**/
class Markdown_parser extends plxPlugin {
	private $rules=array();

	public function __construct($default_lang) {
		# appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);
		$r="\n\n";
		$s="&nbsp;";
		$n="\n";
		$sp1='<span class="';
		$sp2='"></span>';
		$this->rules=array(
			#tag 						replace with 		if txt selected   		title=""   					class=""
			'h1'               		 		=>['# '					,"# %$n"				,'grand titre '					,''],
			'h2'               		 		=>['## '					,"## %$n"				,'titre moyen'					,''],
			'h3'               		 		=>['### '					,"### %$n"				,'titre 3'						,''],
			'h4'               		 		=>['#### '					,"#### %$n"				,'titre 4'						,''],
			'h5'               		 		=>['##### '				,"##### %$n"			,'titre 5'						,''],
			'h6'               		 		=>['###### '				,"###### %$n"			,'titre 6'						,''],
			$sp1.'icon-float-left'.$sp2     =>["[fleft]text[/fleft]"			,"[fleft]%[/fleft]"				,'float left'						,''],
			$sp1.'icon-float-right'.$sp2     =>["[fright]text[/fright]"			,"[fright]%[/fright]"				,'float right'						,''],
			$sp1.'icon-paragraph'.$sp2     =>["[p]text[/p]"			,"[p]%[/p]"				,'block'						,''],
			$sp1.'icon-picture'.$sp2     =>['![alt](URL)'			,'![alt](%)'				,'image'						,''],
			'<span>🎜</span>'     =>['<audio controls><source src=\'URL\'></audio>'			,'<audio controls><source src=\'%\'></audio>'				,'audio'						,''],
			'<span>🎞</span>'     =>['<video controls><source src=\'URL\'></video>'			,'<video controls><source src=\'%\'></video>'				,'video'						,''],
			$sp1.'icon-link'.$sp2     =>['[texte](lien)'			,'[texte](%)'			,'lien'							,''],
			$sp1.'icon-code'.$sp2     =>["$r<pre><code>$n code$n</code></pre>$r"	,"<pre><code>$n%$n</code></pre>"		,'code'							,''],
			$sp1.'icon-quote'.$sp2     =>['>'						,"$r>%$r"				,'citation'						,''],
			$sp1.'icon-ellipsis'.$sp2     =>['***'					,''						,'ligne de séparation'			,''],
			$sp1.'icon-ret'.$sp2     =>["$r"					,"$r"					,'retour chariot forcé'			,''],
			$sp1.'icon-left'.$sp2     =>["[left]text[/left]"					,"[left]%[/left]"					,'aligner à gauche'			,''],
			$sp1.'icon-center'.$sp2     =>["[center]text[/center]"					,"[center]%[/center]"					,'centrer'			,''],
			$sp1.'icon-right'.$sp2     =>["[right]text[/right]"					,"[right]%[/right]"					,'aligner à droite'			,''],

			$sp1.'col-25'.$sp2     =>["[col25]text[/col25]"					,"[col25]%[/col25]"					,'colonne 25%'			,''],
			$sp1.'col-33'.$sp2     =>["[col33]text[/col33]"					,"[col33]%[/col33]"					,'colonne 33%'			,''],
			$sp1.'col-50'.$sp2     =>["[col50]text[/col50]"					,"[col50]%[/col50]"					,'colonne 50%'			,''],
			$sp1.'col-75'.$sp2     =>["[col75]text[/col75]"					,"[col75]%[/col75]"					,'colonne 75%'			,''],
			
			$sp1.'icon-italic'.$sp2     =>['*text*'				,'*%*'					,'italique'						,'italic'],
			$sp1.'icon-bold'.$sp2     =>['**text**'				,'**%**'				,'gras'							,'bold'],
			$sp1.'icon-italic bold'.$sp2     =>['**_text_**'			,'**_%_**'				,'gras+italique'				,'bold italic'],
			$sp1.'icon-strike'.$sp2     =>['~~text~~'				,'~~%~~'				,'texte barré'					,'strike'],
			$sp1.'icon-underline'.$sp2     =>['[u]text[/u]'				,'[u]%[/u]'				,'souligné'					,''],
			$sp1.'icon-numbered'.$sp2     =>["1.text$r"				,"1.%$r 2."				,'liste numérotée'				,''],
			$sp1.'icon-bullet'.$sp2     =>["* text$r"				,"* %$r* "				,'liste normale'				,''],
			$sp1.'icon-stop 1'.$sp2     =>["[red]text[/red]"  		,"[red]%[/red]"			,'rouge'						,'color red'],
			$sp1.'icon-stop 2'.$sp2     =>["[orange]text[/orange]" ,"[orange]%[/orange]"	,'orange'						,'color orange'],
			$sp1.'icon-stop 3'.$sp2     =>["[blue]text[/blue]"  	,"[blue]%[/blue]"		,'bleu'							,'color blue'],
			$sp1.'icon-stop 4'.$sp2     =>["[green]text[/green]"  	,"[green]%[/green]"		,'vert'							,'color green'],
			$sp1.'icon-stop 5'.$sp2     =>["[brown]text[/brown]"  	,"[brown]%[/brown]"		,'marron'						,'color brown'],
			$sp1.'icon-stop 6'.$sp2     =>["[grey]text[/grey]"  	,"[grey]%[/grey]"		,'gris'							,'color grey'],
			$sp1.'icon-stop 7'.$sp2     =>["[violet]text[/violet]" ,"[violet]%[/violet]"	,'violet'						,'color violet'],

			
			);
				
		# Declaration d'un hook (existant ou nouveau)
		$this->addHook('AdminArticlePreview','AdminArticlePreview');
		$this->addHook('AdminArticleTop','AdminArticleTop');
		$this->addHook('markdownAssets','AdminArticleTop');
		$this->addHook('AdminArticleFoot','AdminArticleFoot');
		$this->addHook('markdownBar','AdminArticleFoot');
		$this->addHook('plxMotorParseArticle','plxMotorParseArticle');
		$this->addHook('markdownJs','markdownJs');
		$this->addHook('parse','parse');

		if (!class_exists('Parsedown')){require_once(PLX_PLUGINS.'Markdown_parser/Parsedown.php');}
	}

	# Activation / desactivation
	public function OnActivate() {
		# code à executer à l’activation du plugin
	}
	public function OnDeactivate() {
		# code à executer à la désactivation du plugin
	}
	

	########################################
	# HOOKS
	########################################


	########################################
	# AdminArticlePreview
	########################################
	# Description:
	public function AdminArticlePreview(){
		echo '<?php
		$art["chapo"]=$plxAdmin->plxPlugins->aPlugins["Markdown_parser"]->parse($art["chapo"]);
		$art["content"]=$plxAdmin->plxPlugins->aPlugins["Markdown_parser"]->parse($art["content"]);
		?>';
	}
	########################################
	# markdownJs
	########################################
	# Description:
	public function markdownJs(){
		echo '<script src="'.PLX_PLUGINS.'Markdown_parser/markdownbar.js"></script>';
	}

	########################################
	# plxMotorParseArticle
	########################################
	# Description:
	public function plxMotorParseArticle(){

		echo '<?php
		if (!defined("PLX_ADMIN")){
			$art["chapo"]=$this->plxPlugins->aPlugins["Markdown_parser"]->parse($art["chapo"]);
			$art["content"]=$this->plxPlugins->aPlugins["Markdown_parser"]->parse($art["content"]);
		}
		?>';
	}

	# "AdminArticleTop"
	public function AdminArticleTop() {
		if (!is_dir(PLX_PLUGINS.'WDD_replace')){
			echo '<script src="'.PLX_PLUGINS.'Markdown_parser/VanillaJS.js"></script>';	
		}
		echo '<link rel="stylesheet" type="text/css" href="'.PLX_PLUGINS.'Markdown_parser/md_editor.css"/>';
	}
	# "AdminArticleFoot"
	public function AdminArticleFoot($target='') {
		if (empty($target)){$t='id_content';}else{$t=str_replace('#','',$target);}
		echo '<div class="markdown_bar" target="'.$target.'"><img class="md_icon" src="'.PLX_PLUGINS.'Markdown_parser/icon.png"/> ';
		foreach($this->rules as $mdcode=>$array){
			echo '<a class="md_button '.$array[3].'" add="'.$array[0].'" replace="'.$array[1].'" title="'.$array[2].'">'.$mdcode.'</a>';
		}
		echo '<a class="md_button" onclick="mediasManager.openPopup(\''.$t.'\',null,function(){alert();});">Media</a>';
		echo '</div>';
			if (!empty($target))	{return;}
		echo '	<script>
					movehere=first("#id_content");
					list=first(".markdown_bar");
					listcontent=list.innerHTML;
					before("#id_content","<div class=\"markdown_bar\" target=\"#id_content\">"+listcontent+"</div>");
					before("#id_chapo","<div class=\"markdown_bar\" target=\"#id_chapo\">"+listcontent+"</div>");
					remove(list);
				</script>';
				$this->markdownJs();	
		
	}
	
	# MarkDown functions 
	###########################
	# from parsedown
	
	private function url2link($url){
	   return preg_replace('!(((?:https?|ftp|file)://|apt:|magnet:)\S+[[:alnum:]]/?)!si','<a href="$1" rel="nofollow">$1</a>',$url);
	}
    public function parse($text){
		$Parsedown = new Parsedown();
		$other_rules=[
			'[red]'=>'<span class="red">',
			'[/red]'=>'</span>',
			'[blue]'=>'<span class="blue">',
			'[/blue]'=>'</span>',
			'[green]'=>'<span class="green">',
			'[/green]'=>'</span>',
			'[grey]'=>'<span class="grey">',
			'[/grey]'=>'</span>',
			'[orange]'=>'<span class="orange">',
			'[/orange]'=>'</span>',
			'[violet]'=>'<span class="violet">',
			'[/violet]'=>'</span>',
			'[brown]'=>'<span class="brown">',
			'[/brown]'=>'</span>',
			'[p]'=>'<p>',
			'[/p]'=>'</p>',
			'[u]'=>'<u>',
			'[/u]'=>'</u>',
			'[left]'=>'<p style="text-align:left">',
			'[/left]'=>'</p>',
			'[center]'=>'<p style="text-align:center">',
			'[/center]'=>'</p>',
			'[right]'=>'<p style="text-align:right">',
			'[/right]'=>'</p>',
			'[fleft]'=>'<div style="float:left;margin:0 10px 5px 0;">',
			'[/fleft]'=>'</div>',
			'[fright]'=>'<div style="float:right;margin:0 0 5px 10px;">',
			'[/fright]'=>'</div>',
			'[col25]'=>'<div class="col sml-3">',
			'[/col25]'=>'</div>',
			'[col33]'=>'<div class="col sml-4">',
			'[/col33]'=>'</div>',
			'[col50]'=>'<div class="col sml-6">',
			'[/col50]'=>'</div>',
			'[col75]'=>'<div class="col sml-9">',
			'[/col75]'=>'</div>',
		];
		return $Parsedown->text(str_replace(array_keys($other_rules),array_values($other_rules),$text));
    }
}





/* Pense-bete:
 * Récuperer des etres du fichier eters.xml
 *	$this->getParam("<nom du etre>")
 *	$this-> setParam ("1", 12345, "numeric")
 *	$this->saveParams()
 *
 *	plxUtils::strCheck($string) : sanitize string
 *
 * 
 * Quelques constantes utiles: 
 * PLX_CORE
 * PLX_ROOT
 * PLX_CHARSET
 * PLX_PLUGINS
 * PLX_CONFIG_PATH
 * PLX_ADMIN (true si on est dans admin)
 * PLX_CHARSET
 * PLX_VERSION
 * PLX_FEED
 *
 * Appel de HOOK dans un thème
 *	eval($plxShow->callHook("ThemeEndHead","1"))  ou eval($plxShow->callHook("ThemeEndHead",array("1","2")))
 *	ou $retour=$plxShow->callHook("ThemeEndHead","1"));
 */